@@ -5,7 +5,7 @@ use warnings;
 
 use base 'TAP::Object';
 
-our $VERSION = '3.43_02';
+our $VERSION = '3.43_03';
 
 # TODO:
 #   Handle blessed object syntax
@@ -22,6 +22,7 @@ my $HASH_LINE    = qr{ ^ ($QQ_STRING|\S+) \s* : \s* (?: (.+?) \s* )? $ }x;
 my $IS_HASH_KEY  = qr{ ^ [\w\'\"] }x;
 my $IS_END_YAML  = qr{ ^ \.\.\. \s* $ }x;
 my $IS_QQ_STRING = qr{ ^ $QQ_STRING $ }x;
+my $IS_ARRAY_LINE = qr{ ^ - \s* ($QQ_STRING|\S+) }x;
 
 # new() implementation supplied by TAP::Object
 
@@ -240,9 +241,17 @@ sub _read_hash {
         my ( $key, $value ) = ( $self->_read_scalar($1), $2 );
         $self->_next;
 
+        my ( $next_line, $next_indent ) = $self->_peek;
+
         if ( defined $value ) {
             $hash->{$key} = $self->_read_scalar($value);
         }
+        elsif (not defined $value                  # no explicit undef ("~") given
+               and $next_indent <= $limit          # next line is same or less indentation
+               and $next_line !~ $IS_ARRAY_LINE)   # arrays can start at same indent
+        {
+            $hash->{$key} = undef;
+        }
         else {
             $hash->{$key} = $self->_read_nested;
         }
@@ -269,7 +278,7 @@ TAP::Parser::YAMLish::Reader - Read YAMLish data from iterator
 
 =head1 VERSION
 
-Version 3.43_02
+Version 3.43_03
 
 =head1 SYNOPSIS
 
